#include "reporting_thread.h"
#include "shared_mem_buffer.h"
#include "hwapi.h"

ReportingThread::ReportingThread(hwinf *hw, QString const &fileToDownload)
  : m_hw(hw)
  , m_fileToDownload(fileToDownload) {
}

ReportingThread::~ReportingThread() {
}

// download thread running in ca-slave sends reports download process to
// update tool
void ReportingThread::run() {

    int cnt = 10;
    while (!m_hw->dcDownloadRunning()) {
        if (--cnt > 0) {
            QThread::sleep(1);
        }
    }
    if (cnt == 0) {
        return;
    }

    while (m_hw->dcDownloadRunning()) {
        uint16_t const cnr = m_hw->dcDownloadGetCurrentBlockNumber();
        uint16_t const tnr = m_hw->dcDownloadGetTotalBlockNumber();

        QString report("");

        if (cnr > 0) {
            report = QString("total blocks %1, current block %2 [%3]")
                    .arg(tnr).arg(cnr).arg((double)(tnr)/(double(cnr)));
        } else {
            report = QString("total blocks %1, current block %2 [0]")
                    .arg(tnr).arg(cnr);
        }

        emit m_hw->hwapi_reportDCDownloadStatus(report);
    }

    uint16_t const cnr = m_hw->dcDownloadGetCurrentBlockNumber();
    uint16_t const tnr = m_hw->dcDownloadGetTotalBlockNumber();

    if (tnr == cnr) {
        m_hw->hwapi_reportDCDownloadSuccess(
            QString("SUCCESS DOWNLOADING") + m_fileToDownload);
    } else {
        m_hw->hwapi_reportDCDownloadFailure(
            QString("ERROR DOWNLOADING %1 (total blocks=%2, sent blocks=%3)")
                .arg(m_fileToDownload).arg(tnr).arg(cnr));
    }
}
